=============
Miscellaneous
=============

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    LazyFrame.cache
    LazyFrame.collect
    LazyFrame.fetch
    LazyFrame.lazy
    LazyFrame.map
    LazyFrame.pipe
    LazyFrame.profile

Read/write logical plan
-----------------------

.. autosummary::
   :toctree: api/

    LazyFrame.deserialize
    LazyFrame.from_json
    LazyFrame.read_json
    LazyFrame.serialize
